(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('react')) :
  typeof define === 'function' && define.amd ? define(['exports', 'react'], factory) :
  (global = global || self, factory(global.googleMapsReactHooks = {}, global.react));
})(this, (function (exports, React) {
  function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

  var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

  /**
   * The map context
   */
  var GoogleMapContext = React__default["default"].createContext({
    loading: true
  });

  /**
   * Hook to get global map instance
   */
  var useGoogleMap = function useGoogleMap() {
    return React.useContext(GoogleMapContext);
  };

  /**
   * Hook to get a Google Maps Places Autocomplete instance
   * monitoring an input field
   */
  var useAutocomplete = function useAutocomplete(props) {
    var inputField = props.inputField,
      options = props.options,
      onPlaceChanged = props.onPlaceChanged;
    var placeChangedHandler = React.useRef(onPlaceChanged);
    var _useGoogleMap = useGoogleMap(),
      map = _useGoogleMap.map;
    var _useState = React.useState(null),
      autocomplete = _useState[0],
      setAutocomplete = _useState[1];
    // Initializes the Google Maps Places Autocomplete
    React.useEffect(function () {
      // Wait for map and input element to be initialized
      if (!map || !inputField) {
        return function () {};
      }
      if (!google.maps.places) {
        throw Error("Autocomplete library missing. Add 'places' to the libraries array of GoogleMapProvider.");
      }
      // Create Autocomplete instance
      var autocompleteInstance = new google.maps.places.Autocomplete(inputField, options);
      setAutocomplete(autocompleteInstance);
      // Add places change listener to Autocomplete
      autocompleteInstance.addListener('place_changed', function () {
        var place = autocompleteInstance.getPlace();
        placeChangedHandler.current && placeChangedHandler.current(place);
      });
      // Clear listeners on unmount
      return function () {
        autocompleteInstance && google.maps.event.clearInstanceListeners(autocompleteInstance);
      };
    }, [map, inputField, options]);
    return autocomplete;
  };

  /**
   * Hook to get Google Maps Places Directions Service instance
   */
  var useDirections = function useDirections(props) {
    if (props === void 0) {
      props = {};
    }
    var _props = props,
      renderOnMap = _props.renderOnMap,
      renderOptions = _props.renderOptions;
    var _useGoogleMap = useGoogleMap(),
      map = _useGoogleMap.map,
      loading = _useGoogleMap.loading;
    // Creates a Directions Service instance
    var directionsService = React.useMemo(function () {
      // Wait for map to be initialized
      if (!map || loading) {
        return null;
      }
      return new google.maps.DirectionsService();
    }, [map, loading]);
    // Creates a Directions Renderer instance
    var directionsRenderer = React.useMemo(function () {
      // Wait for map to be initialized
      if (!map || !renderOnMap) {
        return null;
      }
      var renderer = new google.maps.DirectionsRenderer(renderOptions);
      renderer.setMap(map);
      return renderer;
    }, [map, renderOnMap]);
    // Updates the directions renderer options
    React.useEffect(function () {
      if (!directionsRenderer) {
        return;
      }
      directionsRenderer.setOptions(renderOptions || {});
    }, [renderOptions]);
    // Custom Directions route request
    var findRoute = React.useCallback(function (request) {
      return new Promise(function (resolve, reject) {
        if (directionsService) {
          directionsService.route(request, function (result, status) {
            if (status === google.maps.DirectionsStatus.OK) {
              resolve(result);
            } else {
              reject(status);
            }
          });
        }
      });
    }, [directionsService]);
    // Custom Directions route request followed by directions rendering
    var findAndRenderRoute = React.useCallback(function (request) {
      return new Promise(function (resolve, reject) {
        if (directionsService) {
          directionsService.route(request, function (result, status) {
            if (status === google.maps.DirectionsStatus.OK) {
              if (directionsRenderer) {
                directionsRenderer.setDirections(result);
              }
              resolve(result);
            } else {
              reject(status);
            }
          });
        }
      });
    }, [directionsService, directionsRenderer]);
    // Renders directions route of given index
    var renderRouteOfIndex = function renderRouteOfIndex(index) {
      if (directionsRenderer) {
        directionsRenderer.setRouteIndex(index);
      }
    };
    return {
      directionsService: directionsService,
      findRoute: directionsService && findRoute,
      findAndRenderRoute: directionsService && directionsRenderer && findAndRenderRoute,
      renderRouteOfIndex: renderRouteOfIndex
    };
  };

  /**
   * Hook to get Distance Matrix Service instance
   */
  var useDistanceMatrix = function useDistanceMatrix() {
    var _useGoogleMap = useGoogleMap(),
      map = _useGoogleMap.map;
    // Creates a Distance Matrix Service instance
    var distanceMatrixService = React.useMemo(function () {
      // Wait for map to be initialized
      if (!map) {
        return null;
      }
      if (!google.maps.DistanceMatrixService) {
        throw Error('Distance Matrix library missing.');
      }
      return new google.maps.DistanceMatrixService();
    }, [map]);
    return distanceMatrixService;
  };

  /**
   * Hook to get Elevation Service instance
   */
  var useElevationService = function useElevationService() {
    var _useGoogleMap = useGoogleMap(),
      map = _useGoogleMap.map;
    // Creates an Elevation Service instance
    var elevationService = React.useMemo(function () {
      // Wait for map to be initialized
      if (!map) {
        return null;
      }
      return new google.maps.ElevationService();
    }, [map]);
    return elevationService;
  };

  /**
   * Hook to get Google Maps Geocoder instance
   */
  var useGeocoder = function useGeocoder() {
    var _useGoogleMap = useGoogleMap(),
      map = _useGoogleMap.map;
    // Creates a Geocoder instance
    var geocoder = React.useMemo(function () {
      // Wait for Google Maps API to be initialized
      if (!map) {
        return null;
      }
      return new google.maps.Geocoder();
    }, [map]);
    return geocoder;
  };

  /**
   * Hook to get Max Zoom Service instance
   */
  var useMaxZoomService = function useMaxZoomService() {
    var _useGoogleMap = useGoogleMap(),
      map = _useGoogleMap.map;
    // Creates a Max Zoom Service instance
    var maxZoomService = React.useMemo(function () {
      // Wait for map to be initialized
      if (!map) {
        return null;
      }
      return new google.maps.MaxZoomService();
    }, [map]);
    return maxZoomService;
  };

  /**
   * Hook to get Google Maps Places Service instance
   */
  var usePlacesService = function usePlacesService() {
    var _useGoogleMap = useGoogleMap(),
      map = _useGoogleMap.map;
    // Creates a Places Service instance
    var placesService = React.useMemo(function () {
      // Wait for map to be initialized
      if (!map) {
        return null;
      }
      if (!google.maps.places) {
        throw Error("Places library missing. Add 'places' to the libraries array of GoogleMapProvider.");
      }
      return new google.maps.places.PlacesService(map);
    }, [map]);
    return placesService;
  };

  exports.useAutocomplete = useAutocomplete;
  exports.useDirections = useDirections;
  exports.useDistanceMatrix = useDistanceMatrix;
  exports.useElevationService = useElevationService;
  exports.useGeocoder = useGeocoder;
  exports.useGoogleMap = useGoogleMap;
  exports.useMaxZoomService = useMaxZoomService;
  exports.usePlacesService = usePlacesService;

}));
